@@ -13,9 +13,9 @@ import pilas
 class Tortuga(Actor):
     "Representa una tortuga que se mueve por la pantalla como la tortuga de Logo."
 
-    def __init__(self):
+    def __init__(self, x=0, y=0):
         imagen = pilas.imagenes.cargar('tortuga.png')
-        Actor.__init__(self, imagen)
+        Actor.__init__(self, imagen, x=x, y=y)
         self.rotacion = 0
         self.pizarra = pilas.actores.Pizarra()
     
