@@ -6,7 +6,6 @@
 #
 # website - http://www.pilas-engine.com.ar
 
-from pilas.actores import Actor
 import pilas
 from PySFML import sf
 
@@ -26,14 +25,6 @@ class Escena:
         pass
 
 
-class Paisaje(Actor, Escena):
-    "Muestra una escena que tiene un fondo de pantalla de paisaje."
-
-    def __init__(self):
-        Escena.__init__(self)
-        Actor.__init__(self, "volley.png")
-        self.z = 100
-
 class Normal(Escena):
     "Representa la escena inicial mas simple."
 
@@ -42,4 +33,4 @@ class Normal(Escena):
         self.fondo = color_de_fondo or pilas.colores.gris
 
     def dibujar(self, aplicacion):
-        aplicacion.Clear(self.fondo)
+        pilas.motor.pintar(self.fondo)
